==> onos-yang-runtime-2.2.0-b5-sources.jar: org/onosproject/yang/gen/v1/ytbrpc/rev20160826/ytbrpc/content/contentinput/InTypedef.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ytbrpc.rev20160826.ytbrpc.content.contentinput;

import java.util.Objects;

/**
 * Represents the implementation of inTypedef.
 */
public final class InTypedef {

    private String string;

    /**
     * Creates an instance of inTypedef.
     */
    private InTypedef() {
    }

    /**
     * Creates an instance of string.
     *
     * @param string value of string
     */
    public InTypedef(String string) {
        this.string = string;
    }

    /**
     * Returns the object of inTypedef for type string.
     *
     * @param value value of inTypedef for type string
     * @return inTypedef for type string
     */
    public static InTypedef of(String value) {
        return new InTypedef(value);
    }

    /**
     * Returns the attribute string.
     *
     * @return string value of string
     */
    public String string() {
        return string;
    }
    /**
     * Sets the attribute string.
     *
     * @param string value of string
     */
    public void string(String string) {
        this.string = string;
    }

    @Override
    public int hashCode() {
        return Objects.hash(string);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof InTypedef) {
            InTypedef other = (InTypedef) obj;
            return
                Objects.equals(string, other.string);
        }
        return false;
    }

    @Override
    public String toString() {
        return string;
    }
    /**
     * Returns the object of inTypedef fromString input String inTypedef.
     *
     * @param valInString value of input String
     * @return inTypedef
     */
    public static InTypedef fromString(String valInString) {
        try {
            String tmpVal = (valInString);
            return of(tmpVal);
        } catch (Exception e) {
            throw new IllegalArgumentException("not a valid input element");
        }
    }
}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ytbrpc/rev20160826/ytbrpc/content/contentinput/InTypedef.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ytbrpc.rev20160826.ytbrpc.content.contentinput;

import java.util.Objects;

/**
 * Represents the implementation of inTypedef.
 */
public final class InTypedef {

    private String string;

    /**
     * Creates an instance of inTypedef.
     */
    private InTypedef() {
    }

    /**
     * Creates an instance of string.
     *
     * @param string value of string
     */
    public InTypedef(String string) {
        this.string = string;
    }

    /**
     * Returns the object of inTypedef for type string.
     *
     * @param value value of inTypedef for type string
     * @return inTypedef for type string
     */
    public static InTypedef of(String value) {
        return new InTypedef(value);
    }

    /**
     * Returns the attribute string.
     *
     * @return string value of string
     */
    public String string() {
        return string;
    }
    /**
     * Sets the attribute string.
     *
     * @param string value of string
     */
    public void string(String string) {
        this.string = string;
    }

    @Override
    public int hashCode() {
        return Objects.hash(string);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof InTypedef) {
            InTypedef other = (InTypedef) obj;
            return
                Objects.deepEquals(string, other.string);
        }
        return false;
    }

    @Override
    public String toString() {
        return string;
    }
    /**
     * Returns the object of inTypedef fromString input String inTypedef.
     *
     * @param valInString value of input String
     * @return inTypedef
     */
    public static InTypedef fromString(String valInString) {
        try {
            String tmpVal = (valInString);
            return of(tmpVal);
        } catch (Exception e) {
            throw new IllegalArgumentException("not a valid input element");
        }
    }
}
